@@ -13,6 +13,26 @@ base_breaks <- function(n = 10) {
 }
 
 
+get_glm_family <- function(fit) {
+  c.f <- class(fit)
+  # ------------------------
+  # do we have glm? if so, get link family. make exceptions
+  # for specific models that don't have family function
+  # ------------------------
+  if (any(c.f %in% c("lme", "plm")))
+    fitfam <- ""
+  else
+    fitfam <- stats::family(fit)$family
+  # --------------------------------------------------------
+  # create logical for family
+  # --------------------------------------------------------
+  binom_fam <- fitfam %in% c("binomial", "quasibinomial")
+  poisson_fam <- fitfam %in% c("poisson", "quasipoisson") ||
+    sjmisc::str_contains(fitfam, "negative binomial", ignore.case = T)
+  return(list(is_bin = binom_fam, is_pois = poisson_fam))
+}
+
+
 # add annotations with table summary
 # here we print out total N of cases, chi-square and significance of the table
 print.table.summary <- function(baseplot,
@@ -403,7 +423,7 @@ crosstabsum <- function(x, grp, weightBy) {
 
 # checks at which position in fitted models factors with
 # more than two levels are located.
-#' @importFrom nlme getResponse getData
+#' @importFrom stats model.matrix
 retrieveModelGroupIndices <- function(models, rem_rows = NULL) {
   # init group-row-indices
   group.pred.rows <- c()
@@ -418,20 +438,8 @@ retrieveModelGroupIndices <- function(models, rem_rows = NULL) {
   for (k in 1:length(models)) {
     # get model
     fit <- models[[k]]
-    # ------------------------
-    # do we have a merMod object?
-    # ------------------------
-    if (length(grep("merMod", class(fit), fixed = T)) > 0) {
-      # if yes, get number of fixed effects
-      no_fixef <- length(attr(attr(fit@frame, "terms"), "predvars.fixed")) - 1
-      # then copy only fixed effects columns
-      fmodel <- fit@frame[, 1:no_fixef]
-    } else if (any(class(fit) == "gls")) {
-      fmodel <- cbind(`y` = nlme::getResponse(fit), nlme::getData(fit))
-    } else {
-      # copy model matrix
-      fmodel <- fit$model
-    }
+    # copy model matrix
+    fmodel <- stats::model.matrix(fit)
     # retrieve all factors from model
     for (grp.cnt in 1:ncol(fmodel)) {
       # get variable
@@ -538,13 +546,13 @@ retrieveModelLabels <- function(models) {
         # as factor levels?
         if (!is.null(pvar.lab) && length(pvar.lab) == pvar.len) {
           # add labels
-          if (!any(fit.labels == pvar.lab[2:pvar.len])) {
+          if (sjmisc::str_contains(fit.labels, pattern = pvar.lab[2:pvar.len], logic = "NOT")) {
             fit.labels <- c(fit.labels, pvar.lab[2:pvar.len])
           }
         } else {
           # add labels
-          if (!any(fit.labels == attr(fit$coefficients[i], "names"))) {
-            fit.labels <- c(fit.labels, attr(fit$coefficients[i], "names"))
+          if (sjmisc::str_contains(fit.labels, pattern = names(stats::coef(fit)[i]), logic = "NOT")) {
+            fit.labels <- c(fit.labels, names(stats::coef(fit)[i]))
           }
         }
       } else {
@@ -552,7 +560,7 @@ retrieveModelLabels <- function(models) {
         lab <- sjmisc::get_label(fit$model[, i])
         # if not, use coefficient name
         if (is.null(lab)) {
-          lab <- attr(fit$coefficients[i], "names")
+          lab <- colnames(stats::model.frame(fit))[i]
         }
         if (!any(fit.labels == lab)) fit.labels <- c(fit.labels, lab)
       }
@@ -629,6 +637,12 @@ unlistlabels <- function(lab) {
 }
 
 
+get_model_response_label <- function(fit) {
+  m_f <- stats::model.frame(fit)
+  sjmisc::get_label(m_f[[1]], def.value = colnames(m_f)[1])
+}
+
+
 #' @title Adjust y range of ggplot-objects
 #' @name adjust_plot_range
 #'
