@@ -178,8 +178,7 @@ sjt.corr <- function(data,
     # if yes, iterate each variable
     for (i in 1:ncol(data)) {
       # retrieve variable name attribute
-      vn <- sjmisc::get_label(data[[i]],
-                        def.value = get_var_name(deparse(substitute(data[[i]]))))
+      vn <- sjmisc::get_label(data[[i]], def.value = colnames(data)[i])
       # if variable has attribute, add to variableLabel list
       if (!is.null(vn)) {
         varlabels <- c(varlabels, vn)
