@@ -23,9 +23,10 @@
 #'          in the output. Note that if multiple variables
 #'          are supplied (if \code{data} is a \code{\link{data.frame}}), the variable 
 #'          labels must be supplied as \code{list} object (see 'Examples').
-#' @param valueLabels list of character vectors that indicate the value labels of  
-#'          \code{data}. Note that if multiple variables are supplied (if \code{data} is a \code{\link{data.frame}}), 
-#'          the value labels must be supplied as nested \code{list} object (see 'Examples').
+#' @param valueLabels character vector that indicate the value labels of  
+#'          \code{data}. Note that if multiple variables are supplied (if \code{data} 
+#'          is a \code{\link{data.frame}}), the value labels must be supplied as 
+#'          \code{list} object (see 'Examples').
 #' @param autoGroupAt numeric value, indicating at which length of unique values of \code{data}, 
 #'          automatic grouping into smaller units is done (see \code{\link[sjmisc]{group_var}}).
 #'          Variables with large numbers of unique values may be too time consuming when 
@@ -194,7 +195,7 @@
 #'                    css.firsttablecol = "color:#003399; font-weight:bold;"))}
 #' 
 #' @importFrom psych describe
-#' @importFrom stats na.omit
+#' @importFrom stats na.omit weighted.mean
 #' @import sjmisc
 #' @export
 sjt.frq <- function(data,
@@ -649,7 +650,7 @@ sjt.frq <- function(data,
         mw <- mean(orivar, na.rm = TRUE)
         sum_var <- orivar
       } else {
-        mw <- weighted.mean(orivar, weightBy, na.rm = TRUE)
+        mw <- stats::weighted.mean(orivar, weightBy, na.rm = TRUE)
         sum_var <- sjmisc::weight(orivar, weightBy)
       }
       descr <- ""
